@@ -13,7 +13,7 @@ import Github.Private
 -- | The list of all gists created by the user 
 -- 
 -- > gists' (Just ("github-username", "github-password")) "mike-burns"
-gists' :: Maybe BasicAuth -> String -> IO (Either Error [Gist])
+gists' :: Maybe GithubAuth -> String -> IO (Either Error [Gist])
 gists' auth userName = githubGet' auth ["users", userName, "gists"]
 
 -- | The list of all public gists created by the user.
@@ -25,7 +25,7 @@ gists = gists' Nothing
 -- | A specific gist, given its id, with authentication credentials
 --
 -- > gist' (Just ("github-username", "github-password")) "225074"
-gist' :: Maybe BasicAuth -> String -> IO (Either Error Gist)
+gist' :: Maybe GithubAuth -> String -> IO (Either Error Gist)
 gist' auth gistId = githubGet' auth ["gists", gistId]
 
 -- | A specific gist, given its id.
